@@ -1,5 +1,5 @@
 # This file is part of ReText
-# Copyright: 2018 Changhee Kim, 2018-2021 Dmitry Shachnev
+# Copyright: 2018 Changhee Kim, 2018-2024 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,9 +15,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from markups import ReStructuredTextMarkup
-from PyQt5.QtCore import Qt
-from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QGridLayout, QLabel, \
-    QSpinBox
+from PyQt6.QtCore import Qt
+from PyQt6.QtWidgets import QDialog, QDialogButtonBox, QGridLayout, QLabel, QSpinBox
 
 
 class InsertTableDialog(QDialog):
